<template>
  <a-card :bordered="false">
    <div v-show="visible">
      <div class="table-page-search-wrapper" @keyup.enter="handleEnter">
        <a-form layout="inline">
          <a-row :gutter="48" v-show="advanced">
            <a-col :md="6" :sm="24">
              <a-form-item label="关键字">
                <a-input v-model="queryParam.keyword" placeholder="请输入名称/类型名称" />
              </a-form-item>
            </a-col>
          </a-row>
          <a-row :gutter="48">
            <a-col :md="24 || 24" :sm="24" style="text-align: right">
              <span class="table-page-search-submitButtons">
                <a-button type="primary" @click="$refs.table.refresh(true)">查询</a-button>
                <a-button style="margin-left: 8px" @click="resetSearchForm">重置</a-button>
                <a @click="()=>{ this.advanced = !this.advanced}" style="margin-left: 8px">
                  {{ advanced ? '收起' : '展开' }}
                  <a-icon :type="advanced ? 'up' : 'down'" />
                </a>
              </span>
            </a-col>
          </a-row>
        </a-form>
      </div>

      <div class="table-operator" style="margin-bottom: 8px;">
        <a-row>
          <a-col :md="16">
            <a-button v-if="$auth('purchase-store-forms-add')" type="primary" icon="plus" @click="handleAdd()">新增</a-button>
            <a-button
              style="margin-left: 8px"
              v-if="$auth('purchase-store-forms-export')"
              type="primary"
              icon="download"
              @click="doExport">导出
            </a-button>
            <a-divider type="vertical" />
            <a-button v-if="$auth('purchase-store-forms-add')" type="primary" icon="plus" @click="handleRouter(1)">预警列表</a-button>
            <a-divider type="vertical" />
            <a-button v-if="$auth('purchase-store-forms-add')" type="primary" icon="plus" @click="handleRouter(2)">备件列表</a-button>
            <a-dropdown v-action:edit v-if="selectedRowKeys.length > 0 && $auth('purchase-store-forms-del')">
              <a-menu slot="overlay">
                <a-popconfirm title="是否要删除所选数据？" @confirm="batchDelete()">
                  <a-menu-item key="1">
                    <a-icon type="delete" />
                    <a>删除</a></a-menu-item>
                </a-popconfirm>
              </a-menu>
              <a-button style="margin-left: 8px">
                批量操作
                <a-icon type="down" />
              </a-button>
            </a-dropdown>
          </a-col>
        </a-row>
      </div>

      <s-table
        ref="table"
        size="default"
        rowKey="id"
        :columns="columns"
        :data="loadData"
        :alert="options.alert"
        :rowSelection="options.rowSelection"
        showPagination="auto"
      >
        <span slot="action" slot-scope="record">
          <template>
            <a @click="handleView(record)">查看修改</a>
            <a-divider type="vertical" />
            <a @click="handleStorePrint(record)">打印</a>
            <!--                   <operation-button
                      v-if="$auth('purchase-store-forms-edit')" @click='handleEdit(record)'
                    >修改</operation-button>-->
            <operation-button
              v-if="$auth('purchase-store-forms-edit') && record.status == 1"
              @click="handleInStoreApply(record)"
            >提交入库</operation-button>
            <!--                    <operation-button
                      v-if="$auth('store-stores-del')"
                      :type='2'
                      title='是否要删除该条数据？'
                      @confirm='batchDelete(record.id)'>删除</operation-button>-->
            <operation-button
              v-if="$auth('purchase-store-forms-edit') && record.status == 0 "
              :type="2"
              title="是否要封存当前采购单？"
              @confirm="batchDelete(record.id)">暂时封存</operation-button>
            <operation-button
              v-if="$auth('purchase-store-forms-edit') && record.status == 4 "
              :type="2"
              title="是否要解封当前采购单？"
              @confirm="batchDelete(record.id)">解除封存</operation-button>
          </template>
        </span>
        <span slot="status" slot-scope="text">
          <badge
            :status="DictCache.COLOR.PURCHASE_FORM_STATUS[text]"
            :text="statusMap[text]" />
        </span>
      </s-table>
    </div>
    <print-modal ref="printModal" @ok="handleOk"/>
    <base-form ref="baseModal" @ok="handleOk" />
    <detail ref="detailModal" @ok="handleOk" />
  </a-card>
</template>

<script>
import { STable, Ellipsis } from '@/components'
import PrintModal from './modules/PrintInStoreForm'
import BaseForm from './modules/BaseForm'
import Detail from './modules/Detail'
import {
  getPurchaseStoreFormPage,
  deletePurchaseStoreForms,
  fetchPurchaseStoreForm,
  exportPurchaseStoreForm,
  applyInStore
} from '@/api/store/purchaseForm'

export default {
  name: 'PurchaseStoreForm',
  components: {
    STable,
    Ellipsis,
    BaseForm,
    PrintModal,
    Detail
  },
  data () {
    return {
      advanced: false,
      visible: true,
      // 查询参数
      queryParam: {},
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: 'index',
          customRender: (text, record, index) => {
            return `${(this.$refs.table.localPagination.current - 1) * this.$refs.table.localPagination.pageSize + index + 1}`
          }
        },
        {
          title: '名称',
          dataIndex: 'name'
        },
        {
          title: '仓库名称',
          dataIndex: 'spareStoreName'
        },
        {
          title: '采购人',
          dataIndex: 'createdUserName'
        },
        {
          title: '状态',
          dataIndex: 'status',
          scopedSlots: { customRender: 'status' }
        },
        {
          title: '采购总价值',
          dataIndex: 'totalAmount',
          customRender: (text, record, index) => {
            return this.BaseTool.Amount.formatter(text)
          }
        },
        {
          title: '采购总数',
          dataIndex: 'totalNum'
        },
        {
          title: '添加时间',
          dataIndex: 'createdTime'
        },
        {
          title: '操作',
          key: 'action',
          width: '250px',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      // 下拉框map
      statusMap: {},
      // 加载数据方法 必须为 Promise 对象
      loadData: parameter => {
        parameter = {
          ...parameter,
          ...this.queryParam,
          dataScope: {
            sortBy: 'desc',
            sortName: 'update_time'
          }
        }
        return getPurchaseStoreFormPage(Object.assign(parameter, this.queryParam))
          .then(res => {
            return res.data
          })
      },
      selectedRowKeys: [],
      selectedRows: [],

      options: {
        alert: {
          show: true,
          clear: () => {
            this.selectedRowKeys = []
          }
        },
        rowSelection: {
          selectedRowKeys: this.selectedRowKeys,
          onChange: this.onSelectChange
        }
      },
      optionAlertShow: false
    }
  },
  created () {
    // 下拉框map
    this.statusMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.PURCHASE_STORE_FORM_STATUS)
    this.tableOption()
  },
  methods: {
    tableOption () {
      if (!this.optionAlertShow) {
        this.options = {
          alert: {
            show: true,
            clear: () => {
              this.selectedRowKeys = []
            }
          },
          rowSelection: {
            selectedRowKeys: this.selectedRowKeys,
            onChange: this.onSelectChange,
            getCheckboxProps: record => ({
              props: {
                disabled: false,
                name: record.id
              }
            })
          }
        }
        this.optionAlertShow = true
      } else {
        this.options = {
          alert: false,
          rowSelection: null
        }
        this.optionAlertShow = false
      }
    },
    batchDelete (id) {
      let ids = []
      if (this.BaseTool.String.isBlank(id)) {
        const length = this.selectedRows.length
        if (length === 0) {
          this.$message.info('请选择要删除的记录')
          return
        }
        ids = this.selectedRows.map(item => item.id)
      } else {
        ids = [id]
      }
      deletePurchaseStoreForms(ids).then(res => {
        this.$message.info('删除成功')
        this.handleOk()
        this.$refs.table.clearSelected()
      })
    },
    handleAdd () {
      this.visible = false
      const modal = this.$refs.baseModal
      modal.base()
    },
    handleEdit (record) {
      this.visible = false
      fetchPurchaseStoreForm({ id: record.id }).then(res => {
        const modal = this.$refs.baseModal
        modal.base(res.data)
      })
    },
    handleView (record) {
      this.visible = false
      fetchPurchaseStoreForm({ id: record.id }).then(res => {
        const modal = this.$refs.detailModal
        modal.base(res.data)
      })
    },
    handleOk (values) {
      this.visible = true
      this.$refs.table.refresh()
    },
    onSelectChange (selectedRowKeys, selectedRows) {
      this.selectedRowKeys = selectedRowKeys
      this.selectedRows = selectedRows
    },
    resetSearchForm () {
      this.queryParam = {}
      this.$refs.table.refresh(true)
    },
    doExport () {
      const parameter = {
        ...this.queryParam
      }
      exportPurchaseStoreForm(parameter).then(file => {
        this.BaseTool.Util.downLoadExportExcel(file)
      })
    },
    handleRouter (numType) {
      var routeUrl = ''
      if (numType === 1) {
        routeUrl = this.$router.resolve({ path: '/store/SpareStoreTotalMinStock' })
      }
      if (numType === 2) {
        routeUrl = this.$router.resolve({ path: '/spare/part/info' })
      }
      window.open(routeUrl.href, '_blank')
    },
    handleEnter () {
      this.$refs.table.refresh(true)
    },
    handleInStoreApply (record) {
      const params = { id: record.id }
      applyInStore(params).then(res => {
        this.$message.info(res.message)
        this.handleOk()
      }).catch(err => {
        console.log(err)
      })
    },
    handleStorePrint (record) {
      this.visible = false
      fetchPurchaseStoreForm({ id: record.id }).then(res => {
        const modal = this.$refs.printModal
        modal.base(res.data)
      })
    }
  }
}
</script>
